@@ -9,8 +9,8 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
-    "Download" : "Descargar",
     "Copy link" : "Copiar liga",
+    "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
     "Add" : "Agregar",
@@ -24,9 +24,9 @@ OC.L10N.register(
     "Settings" : "Settings",
     "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
+    "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
     "Title" : "Título",
-    "Address book" : "Libreta de direcciones",
     "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
@@ -43,6 +43,7 @@ OC.L10N.register(
     "Moderator" : "Moderador",
     "Admin" : "Administración",
     "Owner" : "Dueño",
+    "Groups" : "Grupos",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
     "Prefix" : "Prefijo",
@@ -90,7 +91,6 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido",
-    "Manager" : "Gerente"
+    "Unknown" : "Desconocido"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
